==> jruby1.1_1.1.6.orig.tar.gz: jruby-1.1.6/src/org/jruby/ast/FixnumNode.java <==
/*
 ***** BEGIN LICENSE BLOCK *****
 * Version: CPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Common Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/cpl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2002 Jan Arne Petersen <jpetersen@uni-bonn.de>
 * Copyright (C) 2002 Benoit Cerrina <b.cerrina@wanadoo.fr>
 * Copyright (C) 2002-2004 Anders Bengtsson <ndrsbngtssn@yahoo.se>
 * Copyright (C) 2004 Thomas E Enebo <enebo@acm.org>
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the CPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the CPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.ast;

import java.util.List;
import org.jruby.Ruby;
import org.jruby.RubyFixnum;

import org.jruby.ast.types.ILiteralNode;
import org.jruby.ast.visitor.NodeVisitor;
import org.jruby.evaluator.Instruction;
import org.jruby.lexer.yacc.ISourcePosition;
import org.jruby.runtime.Block;
import org.jruby.runtime.ThreadContext;
import org.jruby.runtime.builtin.IRubyObject;

/** 
 * Represents an integer literal.
 */
public class FixnumNode extends Node implements ILiteralNode {
    private long value;
    private RubyFixnum fixnum;

    public FixnumNode(ISourcePosition position, long value) {
        super(position, NodeType.FIXNUMNODE);
        this.value = value;
    }

    public Instruction accept(NodeVisitor iVisitor) {
        return iVisitor.visitFixnumNode(this);
    }

    /**
     * Gets the value.
     * @return Returns a long
     */
    public long getValue() {
        return value;
    }
    
    public void setValue(long value) {
        // This should never happen past parse, but just bulletproof this just in case
        if (fixnum != null) {
            fixnum = null;
        }
        this.value = value;
    }
    
    public RubyFixnum getFixnum(Ruby runtime) {
        if (fixnum == null) {
            return fixnum = RubyFixnum.newFixnum(runtime, value);
        }
        return fixnum;
    }
    
    public List<Node> childNodes() {
        return EMPTY_LIST;
    }

    @Override
    public IRubyObject interpret(Ruby runtime, ThreadContext context, IRubyObject self, Block aBlock) {
        return getFixnum(runtime);
    }
    
    @Override
    public IRubyObject when(WhenNode whenNode, IRubyObject whenValue, ThreadContext context, Ruby runtime, IRubyObject self, Block aBlock) {
        interpret(runtime, context, self, aBlock); // For thread polling...maybe we can remove

        if (whenValue == null) return whenNode.interpret(runtime, context, self, aBlock);
        if (whenValue instanceof RubyFixnum) {
            if (((RubyFixnum) whenValue).getLongValue() == value) {
                return whenNode.interpret(runtime, context, self, aBlock);
            }
        } else {
            return super.when(whenNode, whenValue, context, runtime, self, aBlock);
        }

        return null;
    }
}

==> jruby_1.5.6.orig.tar.gz: jruby-1.5.6/src/org/jruby/ast/FixnumNode.java <==
/*
 ***** BEGIN LICENSE BLOCK *****
 * Version: CPL 1.0/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Common Public
 * License Version 1.0 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.eclipse.org/legal/cpl-v10.html
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * Copyright (C) 2002 Jan Arne Petersen <jpetersen@uni-bonn.de>
 * Copyright (C) 2002 Benoit Cerrina <b.cerrina@wanadoo.fr>
 * Copyright (C) 2002-2004 Anders Bengtsson <ndrsbngtssn@yahoo.se>
 * Copyright (C) 2004 Thomas E Enebo <enebo@acm.org>
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the CPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the CPL, the GPL or the LGPL.
 ***** END LICENSE BLOCK *****/
package org.jruby.ast;

import java.util.List;
import org.jruby.Ruby;
import org.jruby.RubyFixnum;

import org.jruby.ast.types.IEqlNode;
import org.jruby.ast.types.ILiteralNode;
import org.jruby.ast.visitor.NodeVisitor;
import org.jruby.lexer.yacc.ISourcePosition;
import org.jruby.runtime.Block;
import org.jruby.runtime.ThreadContext;
import org.jruby.runtime.builtin.IRubyObject;

/** 
 * Represents an integer literal.
 */
public class FixnumNode extends Node implements ILiteralNode, IEqlNode {
    private long value;
    private RubyFixnum fixnum;

    public FixnumNode(ISourcePosition position, long value) {
        super(position);
        this.value = value;
    }

    public Object accept(NodeVisitor iVisitor) {
        return iVisitor.visitFixnumNode(this);
    }

    public NodeType getNodeType() {
        return NodeType.FIXNUMNODE;
    }

    /**
     * Gets the value.
     * @return Returns a long
     */
    public long getValue() {
        return value;
    }
    
    public void setValue(long value) {
        // This should never happen past parse, but just bulletproof this just in case
        if (fixnum != null) {
            fixnum = null;
        }
        this.value = value;
    }
    
    public RubyFixnum getFixnum(Ruby runtime) {
        if (fixnum == null) {
            return fixnum = RubyFixnum.newFixnum(runtime, value);
        }
        return fixnum;
    }
    
    public List<Node> childNodes() {
        return EMPTY_LIST;
    }

    @Override
    public IRubyObject interpret(Ruby runtime, ThreadContext context, IRubyObject self, Block aBlock) {
        return getFixnum(runtime);
    }
    
    public boolean eql(IRubyObject otherValue, ThreadContext context, Ruby runtime, IRubyObject self, Block aBlock) {
        if (otherValue instanceof RubyFixnum) return value == ((RubyFixnum)otherValue).getLongValue();

        return getFixnum(runtime).op_equal(context, otherValue).isTrue();
    }
}
